within PropulsionSystem.BaseClasses.BasicElements;

partial model TurbineBase02
  /********************************************************
            imports
      ********************************************************/
  import Modelica.Constants;
  import PropulsionSystem.Types.switches;
  import Streams = Modelica.Utilities.Streams;
  import Units= Modelica.SIunits;
  /********************************************************
                   Declaration
      ********************************************************/
  /* ---------------------------------------------
          Package
      --------------------------------------------- */
  replaceable package Medium = Modelica.Media.Interfaces.PartialMedium annotation(
    choicesAllMatching = true);
  /* ---------------------------------------------
          switch
      --------------------------------------------- */
  parameter Boolean allowAbnormalOperation = false "= true to allow turbine to operate as 'compressor' where PR<=1, false to restrict 1<PR" annotation(
    Dialog(tab = "Assumptions"),
    Evaluate = true);
  parameter Boolean allowFlowReversal = false "= true to allow flow reversal, false restricts to design direction (port_a -> port_b)" annotation(
    Dialog(tab = "Assumptions"),
    Evaluate = true);
  parameter Boolean printCmd = false "" annotation(
    Evaluate = true,
    HideResult = true,
    choices(checkBox = true),
    Dialog(tab = "debug setting"));
  /* ---------------------------------------------
          parameters
      --------------------------------------------- */
  //********** Initialization Parameters **********
  //--- fluid_1, port_1 ---
  parameter Units.MassFlowRate m_flow1_init(displayUnit = "kg/s") = 1.0 "" annotation(
    Dialog(tab = "Initialization", group = "fluid_1"));
  parameter Units.Pressure p1_init(displayUnit = "Pa") = PR_init * 101.3 * 1000 "" annotation(
    Dialog(tab = "Initialization", group = "fluid_1"));
  parameter Units.Temperature T1_init(displayUnit = "K") = 1600 "" annotation(
    Dialog(tab = "Initialization", group = "fluid_1"));
  parameter Units.SpecificEnthalpy h1_init(displayUnit = "J/kg") = 1600 * 1.004 * 1000 "" annotation(
    Dialog(tab = "Initialization", group = "fluid_1"));
  //--- fluid_2, port_2 ---
  parameter Units.MassFlowRate m_flow2_init(displayUnit = "kg/s") = -1.0 * m_flow1_init "" annotation(
    Dialog(tab = "Initialization", group = "fluid_2"));
  parameter Units.Pressure p2_init(displayUnit = "Pa") = 5.0 * 101.3 * 1000 "" annotation(
    Dialog(tab = "Initialization", group = "fluid_2"));
  parameter Units.Temperature T2_init(displayUnit = "K") = 1000 "" annotation(
    Dialog(tab = "Initialization", group = "fluid_2"));
  parameter Units.SpecificEnthalpy h2_init(displayUnit = "J/kg") = T2_init * 1.004 * 1000 "" annotation(
    Dialog(tab = "Initialization", group = "fluid_2"));
  //--- flange_1 ---
  parameter Units.Torque tau1_init = pwr_init / (Nmech_init * 2.0 * Modelica.Constants.pi / 60.0) "" annotation(
    Dialog(tab = "Initialization", group = "flange_1"));
  parameter Units.Angle phi1_init = phi_init "" annotation(
    Dialog(tab = "Initialization", group = "flange_1"));
  //--- flange_2 ---
  parameter Units.Torque tau2_init = 0.1 "" annotation(
    Dialog(tab = "Initialization", group = "flange_2"));
  parameter Units.Angle phi2_init = phi_init "" annotation(
    Dialog(tab = "Initialization", group = "flange_2"));
  //--- others ---
  parameter Real PR_init = 4.0 "" annotation(
    Dialog(tab = "Initialization", group = "others"));
  parameter Real eff_init = 0.8 "" annotation(
    Dialog(tab = "Initialization", group = "others"));
  parameter Units.Conversions.NonSIunits.AngularVelocity_rpm Nmech_init = 3000.0 "" annotation(
    Dialog(tab = "Initialization", group = "others"));
  parameter Real NcqNcDes_1_init = 1.0 "" annotation(
    Dialog(tab = "Initialization", group = "others"));
  parameter Real NqNdes_init = NcqNcDes_1_init "" annotation(
    Dialog(tab = "Initialization", group = "others"));
  parameter Units.MassFlowRate Wc_1_init = m_flow1_init "" annotation(
    Dialog(tab = "Initialization", group = "others"));
  parameter Units.Conversions.NonSIunits.AngularVelocity_rpm Nc_1_init = Nmech_init "" annotation(
    Dialog(tab = "Initialization", group = "others"));
  parameter Units.SpecificEnthalpy dht_init = 430000.0 "" annotation(
    Dialog(tab = "Initialization", group = "others"));
  parameter Units.SpecificEnthalpy dht_is_init = 540000.0 "" annotation(
    Dialog(tab = "Initialization", group = "others"));
  parameter Units.Power pwr_init = -4.0 * 10.0 ^ 5 "" annotation(
    Dialog(tab = "Initialization", group = "others"));
  parameter Units.Torque trq_init = pwr_init / (Nmech_init * 2.0 * Modelica.Constants.pi / 60.0) "" annotation(
    Dialog(tab = "Initialization", group = "others"));
  parameter Units.Angle phi_init = 1.0 "" annotation(
    Dialog(tab = "Initialization", group = "others"));
  parameter Units.SpecificEntropy s_fluid_1_init = 7800.0 "" annotation(
    Dialog(tab = "Initialization", group = "others"));
  parameter Units.SpecificEntropy s_fluid_2_init = 7900.0 "" annotation(
    Dialog(tab = "Initialization", group = "others"));
  /* ---------------------------------------------
          Internal variables
      --------------------------------------------- */
  Units.SpecificEntropy s_fluid_1(start = s_fluid_1_init) "specific entropy, fluid_1" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  Units.SpecificEntropy s_fluid_2(start = s_fluid_2_init) "specific entropy, fluid_2" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  Units.Power pwr(start = pwr_init) "power via shaft, positive if fluid generates power" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  Units.Power pwrMech(start=pwr_init) "positive if fluid generates power" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  Units.Torque trq(start = trq_init) "trq via shaft" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  Units.Power pwr_inv(start = -1.0 * pwr_init) "power via shaft" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  Units.Torque trq_inv(start = -1.0 * trq_init) "trq via shaft" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  Units.AngularVelocity omega(start = Nmech_init * 2.0 * Modelica.Constants.pi / 60.0) "mechanical rotation speed, rad/sec" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  Units.Angle phi(start = phi_init) "mechanical rotation displacement, rad" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  Units.Conversions.NonSIunits.AngularVelocity_rpm Nmech(start = Nmech_init) "mechanical rotation speed, rpm" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  Units.MassFlowRate Wc_1(start = Wc_1_init) "corrected mass flow rate" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  Units.Conversions.NonSIunits.AngularVelocity_rpm Nc_1(start = Nc_1_init) "corrected rotation speed, rpm" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  Real PR(start = PR_init, min = if allowAbnormalOperation then 0.0 else 1.0 + 1.0e-10) "pressure ratio" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  Real eff(start = eff_init, min = 0.0, max = 1.0) "adiabatic efficiency" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  Units.SpecificEnthalpy dht_is(start = dht_is_init, min = if allowAbnormalOperation then -Constants.inf else 0.0 + 1.0e-10) "specific enthalpy change in isentropic compression" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  Units.SpecificEnthalpy dht(start = dht_init, min = if allowAbnormalOperation then -Constants.inf else 0.0 + 1.0e-10) "specific enthalpy change in non-isentropic compression" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  Units.SpecificEnthalpy h_2is(start = h1_init - dht_is_init) "" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  
  Units.MassFlowRate m_flow_max(start = m_flow1_init) "" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  Units.MassFlowRate m_flow_min(start = m_flow2_init) "" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  /*
  */
  //********** variables relative to design point **********
  inner Real NcqNcDes_1(start = NcqNcDes_1_init) "ratio of corrected rotational speed with respect to design pt. speed" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  Real NqNdes(start = NqNdes_init) "ratio of mech. rotational speed with respect to design pt. speed" annotation(
    Dialog(tab = "Variables", group = "start attribute", enable = false, showStartAttribute = true));
  /* ---------------------------------------------
          Internal objects
      --------------------------------------------- */
  inner outer PropulsionSystem.EngineSimEnvironment environment "System wide properties";
  Medium.BaseProperties fluid_1(p(start = p1_init, min = 0.0 + 1.0e-10), T(start = T1_init, min = 0.0 + 1.0e-10), state.p(start = p1_init, min = 0.0 + 1.0e-10), state.T(start = T1_init, min = 0.0 + 1.0e-10), h(start = h1_init, min = 0.0 + 1.0e-10)) "flow station of inlet";
  Medium.BaseProperties fluid_2(p(start = p2_init, min = 0.0 + 1.0e-10), T(start = T2_init, min = 0.0 + 1.0e-10), state.p(start = p2_init, min = 0.0 + 1.0e-10), state.T(start = T2_init, min = 0.0 + 1.0e-10), h(start = h2_init, min = 0.0 + 1.0e-10)) "flow station of outlet";
  
  
  /* ---------------------------------------------
          Declare function objects
  --------------------------------------------- */
  function fluidOp= PropulsionSystem.Functions.TurbineFunctionPackage.TurbineFluidOperation00(redeclare package inFuncMedium=Medium);
  function mechOp= PropulsionSystem.Functions.TurbineFunctionPackage.TurbineMechOperation00;
  
  
  /* ---------------------------------------------
          Interface
      --------------------------------------------- */
  Modelica.Fluid.Interfaces.FluidPort_a port_1(redeclare package Medium = Medium, m_flow(start = m_flow1_init, min = if allowFlowReversal then -Constants.inf else 0.0), h_outflow(start = h1_init, min = 0.0 + 1.0e-10), p(start = p1_init, min = 0.0 + 1.0e-10)) "" annotation(
    Placement(visible = true, transformation(origin = {-100, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-60, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Fluid.Interfaces.FluidPort_b port_2(redeclare package Medium = Medium, m_flow(start = m_flow2_init, max = if allowFlowReversal then +Constants.inf else 0.0), h_outflow(start = h2_init, min = 0.0 + 1.0e-10), p(start = p2_init, min = 0.0 + 1.0e-10)) "" annotation(
    Placement(visible = true, transformation(origin = {100, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {62, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_1(tau(start = tau1_init), phi(start = phi1_init)) "" annotation(
    Placement(visible = true, transformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-98, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_2(tau(start = tau2_init), phi(start = phi2_init)) "" annotation(
    Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  PropulsionSystem.Types.ElementBus elementBus1 annotation(
    Placement(visible = true, transformation(origin = {100, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  //******************************************************************************************
protected
  //********** variables of design point **********
  parameter Units.MassFlowRate Wc_1_des(fixed = false) "corrected mass flow rate, fluid_1, design point" annotation(
    HideResult = false);
  parameter Units.Conversions.NonSIunits.AngularVelocity_rpm NmechDes(fixed = false) "mechanical rotation speed, rpm" annotation(
    HideResult = false);
  parameter Units.Conversions.NonSIunits.AngularVelocity_rpm Nc_1_des(fixed = false) annotation(
    HideResult = false);
  parameter Real PRdes(fixed = false) annotation(
    HideResult = false);
  parameter Real effDes(fixed = false) annotation(
    HideResult = false);
  //******************************************************************************************
initial algorithm
//******************************************************************************************
initial equation
  if printCmd == true then
    Streams.print("initialization");
    Streams.print(getInstanceName());
    Streams.print("omega= " + String(omega));
    Streams.print("Nmech= " + String(Nmech));
  end if;
  assert(noEvent(Modelica.Constants.small < abs(omega)), getInstanceName() + ", omega=" + String(omega), AssertionLevel.error);
  assert(noEvent(Modelica.Constants.small < abs(Nmech)), getInstanceName() + ", Nmech=" + String(Nmech), AssertionLevel.error);
  assert(noEvent(Modelica.Constants.small < abs(Nc_1)), getInstanceName() + ", Nc_1=" + String(Nc_1), AssertionLevel.error);
  assert(noEvent(Modelica.Constants.small < fluid_1.p), getInstanceName() + ", fluid_1.p=" + String(fluid_1.p), AssertionLevel.error);
  assert(noEvent(Modelica.Constants.small < fluid_1.T), getInstanceName() + ", fluid_1.T=" + String(fluid_1.T), AssertionLevel.error);
  assert(noEvent(Modelica.Constants.small < fluid_1.h), getInstanceName() + ", fluid_1.h=" + String(fluid_1.h), AssertionLevel.error);
//assert((omega<Modelica.Constants.small) or (Modelica.Constants.small<omega), getInstanceName()+", omega="+String(omega), AssertionLevel.warning);
  Wc_1_des = Wc_1;
  Nc_1_des = Nc_1;
//******************************************************************************************
algorithm
  if printCmd == true then
    assert(PR < 0.0, getInstanceName() + ", PR got less than 0" + ", fluid_1.p=" + String(fluid_1.p) + ", fluid_2.p=" + String(fluid_2.p), AssertionLevel.warning);
    Streams.print(getInstanceName());
    Streams.print("time= " + String(time));
    Streams.print("omega= " + String(omega));
    Streams.print("Nmech= " + String(Nmech));
  end if;
//******************************************************************************************
equation
  if printCmd == true then
    Streams.print(getInstanceName());
    Streams.print("omega= " + String(omega));
    Streams.print("Nmech= " + String(Nmech));
    assert(0.0 < fluid_1.p, getInstanceName() + ", fluid_1.p=" + String(fluid_1.p), AssertionLevel.warning);
    assert(0.0 < fluid_2.p, getInstanceName() + ", fluid_2.p=" + String(fluid_2.p), AssertionLevel.warning);
  end if;
  assert(noEvent(Modelica.Constants.small < abs(omega)), getInstanceName() + ", omega=" + String(omega), AssertionLevel.error);
  assert(noEvent(Modelica.Constants.small < abs(Nmech)), getInstanceName() + ", Nmech=" + String(Nmech), AssertionLevel.error);
  assert(noEvent(Modelica.Constants.small < abs(Nc_1)), getInstanceName() + ", Nc_1=" + String(Nc_1), AssertionLevel.error);
  assert(noEvent(Modelica.Constants.small < fluid_1.p), getInstanceName() + ", fluid_1.p=" + String(fluid_1.p), AssertionLevel.error);
  assert(noEvent(Modelica.Constants.small < fluid_1.T), getInstanceName() + ", fluid_1.T=" + String(fluid_1.T), AssertionLevel.error);
  assert(noEvent(Modelica.Constants.small < fluid_1.h), getInstanceName() + ", fluid_1.h=" + String(fluid_1.h), AssertionLevel.error);
/**/
  when noEvent(abs(omega) < Modelica.Constants.small) then
    reinit(omega, Nmech_init * 2.0 * Modelica.Constants.pi / 60.0);
  end when;
  when noEvent(abs(Nmech) < Modelica.Constants.small) then
    reinit(Nmech, Nmech_init);
  end when;
  when noEvent(abs(Nc_1) < Modelica.Constants.small) then
    reinit(Nc_1, Nc_1_init);
  end when;
  when noEvent(fluid_1.p < Modelica.Constants.small) then
    reinit(fluid_1.p, p1_init);
  end when;
  when noEvent(fluid_1.T < Modelica.Constants.small) then
    reinit(fluid_1.T, T1_init);
  end when;
  when noEvent(fluid_1.h < Modelica.Constants.small) then
    reinit(fluid_1.h, h1_init);
  end when;
/* ---------------------------------------------
    Connections, interface <-> internal variables
  --------------------------------------------- */
//-- fluidPort_1 --
  fluid_1.p = port_1.p;
  fluid_1.h = actualStream(port_1.h_outflow);
  fluid_1.Xi = actualStream(port_1.Xi_outflow);
//-- fluidPort_2 --
  fluid_2.p = port_2.p;
  fluid_2.h = actualStream(port_2.h_outflow);
  fluid_2.Xi = actualStream(port_2.Xi_outflow);
// distinguish inlet side
  m_flow_max = max(port_1.m_flow, port_2.m_flow);
  m_flow_min = min(port_1.m_flow, port_2.m_flow);
  if allowFlowReversal == false then
    port_1.h_outflow = fluid_1.h;
    port_1.Xi_outflow = fluid_1.Xi;
  else
    if m_flow_max == port_1.m_flow then
      port_1.h_outflow = fluid_1.h;
      port_1.Xi_outflow = fluid_1.Xi;
    elseif m_flow_max == port_2.m_flow then
      port_2.h_outflow = fluid_2.h;
      port_2.Xi_outflow = fluid_2.Xi;
    else
      port_1.h_outflow = fluid_1.h;
      port_1.Xi_outflow = fluid_1.Xi;
    end if;
  end if;
//-- shaft --
  flange_1.phi = phi;
  flange_2.phi = phi;
  der(phi) = omega;
  trq = flange_1.tau + flange_2.tau;
  
/* ---------------------------------------------
  Eqns describing physics
  --------------------------------------------- */
  port_1.m_flow + port_2.m_flow = 0.0;
  
  (fluid_2.p, fluid_2.h, fluid_2.X, h_2is, pwr)
    = fluidOp(state_1= fluid_1.state, m_flow1=port_1.m_flow, PR=PR, eff=eff);
  pwrMech=mechOp(omega=omega, trq=trq);
  pwr=pwrMech;
//-----
  Wc_1 = port_1.m_flow * sqrt(fluid_1.T / environment.Tstd) / (fluid_1.p / environment.pStd);
  Nc_1 = Nmech / sqrt(fluid_1.T / environment.Tstd);
  dht= fluid_2.h - fluid_1.h;
  dht_is= h_2is - fluid_1.h;
  
  
  Nmech = omega * 60.0 / (2.0 * Modelica.Constants.pi);
  pwr_inv = -1 * pwr;
  trq_inv = -1 * trq;
  s_fluid_1 = Medium.specificEntropy(fluid_1.state);
  s_fluid_2 = Medium.specificEntropy(fluid_2.state);
//-- variables relative to design point --
  NqNdes = Nmech / NmechDes;
  NcqNcDes_1 = Nc_1 / Nc_1_des;
/********************************************************
  Graphics
********************************************************/
  annotation(
    Icon(graphics = {Polygon(origin = {30, 0}, fillColor = {255, 170, 0}, fillPattern = FillPattern.HorizontalCylinder, points = {{-90, 0}, {-90, -20}, {30, -80}, {30, 80}, {-90, 20}, {-90, 0}}), Rectangle(origin = {84, 6}, fillPattern = FillPattern.Solid, extent = {{-24, 4}, {16, -16}}), Rectangle(origin = {-86, 6}, fillPattern = FillPattern.Solid, extent = {{-12, 4}, {26, -16}}), Text(origin = {-43, 117}, extent = {{-57, 5}, {143, -15}}, textString = "%name"), Rectangle(origin = {-57, 30}, fillColor = {165, 165, 165}, fillPattern = FillPattern.Solid, extent = {{-3, 52}, {1, -10}})}, coordinateSystem(initialScale = 0.1)),
    __OpenModelica_simulationFlags(lv = "LOG_STATS", s = "dassl"));
end TurbineBase02;
